
============
Input/output
============
.. currentmodule:: polars


CSV
~~~
.. autosummary::
   :toctree: api/

   read_csv
   scan_csv
   DataFrame.to_csv

Feather/ IPC
~~~~~~~~~~~~
.. autosummary::
   :toctree: api/

   read_ipc
   read_ipc_schema
   DataFrame.to_ipc

Parquet
~~~~~~~
.. autosummary::
   :toctree: api/

   read_parquet
   scan_parquet
   DataFrame.to_parquet

SQL
~~~
.. autosummary::
   :toctree: api/

   read_sql

JSON
~~~~
.. autosummary::
   :toctree: api/

   read_json
   DataFrame.to_json
